@@ -200,6 +200,8 @@ _title_id(id3_t tag)
   case ID3_VERSION_2_3:
   case ID3_VERSION_2_4:
     return "TIT2";
+  default:
+    ;
   }
   return NULL;
 }
@@ -213,6 +215,8 @@ _artist_id(id3_t tag)
   case ID3_VERSION_2_3:
   case ID3_VERSION_2_4:
     return "TPE1";
+  default:
+    ;
   }
   return NULL;
 }
@@ -226,6 +230,8 @@ _album_id(id3_t tag)
   case ID3_VERSION_2_3:
   case ID3_VERSION_2_4:
     return "TALB";
+  default:
+    ;
   }
   return NULL;
 }
@@ -239,6 +245,8 @@ _genre_id(id3_t tag)
   case ID3_VERSION_2_3:
   case ID3_VERSION_2_4:
     return "TCON";
+  default:
+    ;
   }
   return NULL;
 }
@@ -253,6 +261,8 @@ _date_id(id3_t tag)
     return "TYER";
   case ID3_VERSION_2_4:
     return "TDRC";
+  default:
+    ;
   }
   return NULL;
 }
@@ -266,6 +276,8 @@ _tracknum_id(id3_t tag)
   case ID3_VERSION_2_3:
   case ID3_VERSION_2_4:
     return "TRCK";
+  default:
+    ;
   }
   return NULL;
 }
